package com.hys.app.service.erp.impl;

import com.hys.app.converter.erp.GoodsConverter;
import com.hys.app.converter.erp.GoodsSnConverter;
import com.hys.app.framework.database.WebPage;
import com.hys.app.framework.database.mybatisplus.base.BaseServiceImpl;
import com.hys.app.framework.exception.ServiceException;
import com.hys.app.mapper.goods.GoodsSnMapper;
import com.hys.app.model.erp.dos.GoodsSnDO;
import com.hys.app.model.erp.dto.GoodsSnCreateDTO;
import com.hys.app.model.erp.dto.GoodsSnDTO;
import com.hys.app.model.erp.dto.GoodsSnQueryParams;
import com.hys.app.model.erp.vo.GoodsSnVO;
import com.hys.app.model.erp.vo.GoodsVO;
import com.hys.app.model.goods.enums.GoodsSnStatusEnums;
import com.hys.app.service.erp.GoodsManager;
import com.hys.app.service.erp.GoodsSnManager;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 商品业务层实现
 *
 * @author 张崧
 * 2023-12-26 15:56:58
 */
@Service
public class GoodsSnManagerImpl extends BaseServiceImpl<GoodsSnMapper, GoodsSnDO> implements GoodsSnManager {

    @Autowired
    private GoodsSnConverter converter;

    @Autowired
    private GoodsManager goodsManager;


    @Override
    public WebPage<GoodsSnVO> list(GoodsSnQueryParams queryParams){
        WebPage<GoodsSnDO> webPage = baseMapper.selectPage(queryParams);
        WebPage<GoodsSnVO> webPage1=converter.convert(webPage);
        for(GoodsSnVO goodsSnVO:webPage1.getData()){
            GoodsVO goodsVO=goodsManager.getInfo(goodsSnVO.getGoodsId());
            goodsSnVO.setGoodsVO(goodsVO);
        }

        return webPage1;
    }

    @Override
    public WebPage<GoodsSnVO> searchCount(GoodsSnQueryParams queryParams) {
        List<GoodsSnDO> goodsSnDOS = baseMapper.getGoodsSnCount(queryParams);

        Long totalQty= baseMapper.getGoodsSnCountQty(queryParams);
        List<GoodsSnVO> goodsSnVOS=converter.convert(goodsSnDOS);

        for(GoodsSnVO item:goodsSnVOS){
            GoodsVO goodsVO=goodsManager.getInfo(item.getGoodsId());
            item.setGoodsVO(goodsVO);
            GoodsSnQueryParams temp=new GoodsSnQueryParams();
            temp.setGoodsId(item.getGoodsId());
            item.setQty(baseMapper.getGoodsSnCountQty(temp));
        }

        WebPage<GoodsSnVO> webPage1=new WebPage<>();
        webPage1.setData(goodsSnVOS);
        webPage1.setPageNo(queryParams.getPageNo());
        webPage1.setDataTotal(totalQty);
        webPage1.setPageSize(queryParams.getPageSize());

        return webPage1;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void add(GoodsSnDTO goodsSnDTO) {
        // 保存GoodsDO
        GoodsSnDO goodsSnDO = converter.convert(goodsSnDTO);
        super.save(goodsSnDO);

    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public void createMore(GoodsSnCreateDTO request) {
        // 保存GoodsDO
        GoodsVO goodsVO=goodsManager.getDetail(request.getGoodsId());
        if(Objects.isNull(goodsVO)){
            throw new ServiceException("商品信息不存在");
        }
        List<GoodsSnDO> list=new ArrayList<>();
        for(int i=0;i<request.getQty();i++){
            GoodsSnDO goodsSnDO=new GoodsSnDO();
            goodsSnDO.setGoodsId(goodsVO.getId());
            goodsSnDO.setSnCode(createGoodsSnCode(goodsVO));
            goodsSnDO.setStatus(GoodsSnStatusEnums.WAIT.name());
            list.add(goodsSnDO);
        }
        super.saveBatch(list);
    }


    /**
     * 生成规则：序号号=商品编号+当前生成时间+4位自然序号
     * 注意：单次生成数量不得超过9999
     * 这个规则要改成：序号号=商品编号+规格编码（4位）+当前生成时间+4位自然序号
     * @param goodsVO
     * @return
     */
    private static String createGoodsSnCode(GoodsVO goodsVO){
        SimpleDateFormat sf=new SimpleDateFormat("yyyyMMddHHmmss");
        Date date =new Date();
        Random random = new Random();
        return goodsVO.getSn()+sf.format(date)+(random.nextInt(9000) + 1000);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void edit(GoodsSnDTO goodsSnDTO) {
        // 参数校验


        // 更新商品
        GoodsSnDO goodsSnDO = converter.convert(goodsSnDTO);
        super.updateById(goodsSnDO);  }

    @Override
    public GoodsSnVO getDetail(Long id) {
        // 商品
        GoodsSnDO goodsSnDO = getById(id);
        GoodsSnVO goodsSnVO= converter.convert(goodsSnDO);
        GoodsVO goodsVO=goodsManager.getDetail(goodsSnDO.getGoodsId());
        goodsSnVO.setGoodsVO(goodsVO);
        return goodsSnVO;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void delete(Long id) {
        // 删除商品
        removeById(id);
    }

}

