package com.hys.app.service.erp.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.yulichang.interfaces.MPJBaseJoin;
import com.hys.app.converter.erp.WarehouseAreaConverter;
import com.hys.app.converter.erp.WarehouseOutItemConverter;
import com.hys.app.framework.database.WebPage;
import com.hys.app.framework.database.mybatisplus.base.BaseServiceImpl;
import com.hys.app.framework.exception.ServiceException;
import com.hys.app.mapper.erp.WarehouseAreaMapper;
import com.hys.app.mapper.erp.WarehouseOutItemMapper;
import com.hys.app.model.erp.dos.WarehouseAreaDO;
import com.hys.app.model.erp.dos.WarehouseDO;
import com.hys.app.model.erp.dos.WarehouseOutItemDO;
import com.hys.app.model.erp.dto.WarehouseAreaQueryParams;
import com.hys.app.model.erp.dto.WarehouseDTO;
import com.hys.app.model.erp.dto.WarehouseOutItemQueryParams;
import com.hys.app.model.erp.vo.WarehouseAreaVO;
import com.hys.app.model.erp.vo.WarehouseOutItemVO;
import com.hys.app.model.erp.vo.WarehouseVO;
import com.hys.app.service.erp.WarehouseAreaManager;
import com.hys.app.service.erp.WarehouseManager;
import com.hys.app.service.erp.WarehouseOutItemManager;
import org.apache.ibatis.session.ResultHandler;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * 出库单商品明细业务层实现
 *
 * @author 张崧
 * @since 2023-12-07 17:06:32
 */
@Service
public class WarehouseAreaManagerImpl extends BaseServiceImpl<WarehouseAreaMapper, WarehouseAreaDO> implements WarehouseAreaManager {

    @Autowired
    private WarehouseAreaConverter converter;

    @Autowired
    private WarehouseManager warehouseManager;

    @Override
    public WebPage<WarehouseAreaVO> list(WarehouseAreaQueryParams queryParams) {
        WebPage<WarehouseAreaDO> webPage = baseMapper.selectPage(queryParams);
        WebPage<WarehouseAreaVO> webPage1=converter.convert(webPage);
        for(WarehouseAreaVO item:webPage1.getData()){
            WarehouseVO warehouseVO=warehouseManager.getDetail(item.getWarehouseId());
            item.setWarehouse(warehouseVO);
        }

        return webPage1;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void add(WarehouseAreaDO warehouseAreaDO) {
        WarehouseAreaDO one = this.baseMapper.selectOne(new LambdaQueryWrapper<WarehouseAreaDO>()
                .eq(WarehouseAreaDO::getWarehouseId, warehouseAreaDO.getWarehouseId())
                .eq(WarehouseAreaDO::getCode, warehouseAreaDO.getCode()));
        if (ObjectUtil.isNotNull(one)){
            throw new ServiceException("该仓库下库位编号已存在");
        }
        save(warehouseAreaDO);
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public void edit(WarehouseAreaDO warehouseAreaDO) {
        if (warehouseAreaDO.getId()<=0) {
            throw new ServiceException("库位信息更新失败,库位信息不存在");
        }

        updateById(warehouseAreaDO);
    }


    @Override
    public WarehouseAreaVO getDetail(Long id) {
        WarehouseAreaVO vo=converter.convert(getById(id));
        if(!Objects.isNull(vo)){
            WarehouseVO warehouseVO=warehouseManager.getDetail(vo.getWarehouseId());
            vo.setWarehouse(warehouseVO);
        }

        return vo;
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public void delete(Long id) {
        removeById(id);
    }


}

